@@ -1,8 +1,7 @@
 from kubernetes import client
-from rich import print
 from rich.panel import Panel
-from rich.console import Console
 
+from hardeneks import console
 from ...resources import Resources
 
 
@@ -12,12 +11,10 @@ def check_metrics_server_is_running(resources: Resources):
         for i in client.CoreV1Api().list_service_for_all_namespaces().items
     ]
 
-    console = Console()
-
     if "metrics-server" in services:
         return True
     else:
-        print(
+        console.print(
             Panel(
                 "[red]Deploy metrics server.",
                 subtitle="[link=https://aws.github.io/aws-eks-best-practices/reliability/docs/application/#run-kubernetes-metrics-server]Click to see the guide[/link]",
@@ -33,12 +30,10 @@ def check_vertical_pod_autoscaler_exists(resources: Resources):
         for i in client.AppsV1Api().list_deployment_for_all_namespaces().items
     ]
 
-    console = Console()
-
     if "vpa-recommender" in deployments:
         return True
     else:
-        print(
+        console.print(
             Panel(
                 "[red]Deploy vertical pod autoscaler if needed.",
                 subtitle="[link=https://aws.github.io/aws-eks-best-practices/reliability/docs/application/#vertical-pod-autoscaler-vpa]Click to see the guide[/link]",
